@@ -40,8 +40,8 @@ ftsm = function (y, order = 6, ngrid = max(500, ncol(y$y)), method = c("classica
     }
     ytsp <- tsp(y$time)
     if (weight == TRUE) {
-	    colmeanrm = matrix(colMeans(sco), dim(sco)[2], 1)
-		scomeanrm = sweep(sco, 2, colmeanrm)
+        colmeanrm = matrix(colMeans(sco), dim(sco)[2], 1)
+        scomeanrm = sweep(sco, 2, colmeanrm)
         coeff <- ts(cbind(rep(1, dim(y$y)[2]), scomeanrm), start = ytsp[1], 
             frequency = ytsp[3])
     }
@@ -49,29 +49,32 @@ ftsm = function (y, order = 6, ngrid = max(500, ncol(y$y)), method = c("classica
         coeff <- ts(y.pca$coeff, start = ytsp[1], frequency = ytsp[3])
     }
     if (weight == TRUE) {
-		my = my + load %*% colmeanrm
+        my = my + load %*% colmeanrm
         basis <- cbind(my, load)
         colnames(basis) = c("mean", paste("phi", 1:order, sep = ""))
         colnames(coeff) = c("mean", paste("beta", 1:order, sep = ""))
-        fits <- fts(y$x, sweep(load %*% t(scomeanrm), 1, my, "+"), start = ytsp[1], frequency = ytsp[3], 
-            xname = y$xname, yname = paste("Fitted", y$yname))
+        fits <- fts(y$x, sweep(load %*% t(scomeanrm), 1, my, 
+            "+"), start = ytsp[1], frequency = ytsp[3], xname = y$xname, 
+            yname = paste("Fitted", y$yname))
     }
     else {
         basis <- y.pca$basis
-        fits <- fts(y$x, basis %*% t(coeff), start = ytsp[1], frequency = ytsp[3], 
-            xname = y$xname, yname = paste("Fitted", y$yname))
+        fits <- fts(1:length(y$x), basis %*% t(coeff), start = ytsp[1], 
+            frequency = ytsp[3], xname = y$xname, yname = paste("Fitted", 
+                y$yname))
+		fits$x = y$x                
     }
     rownames(basis) <- paste(y$x)
-    res <- fts(y$x, y$y - fits$y, start = ytsp[1], frequency = ytsp[3], xname = y$xname, 
-        yname = paste("Residuals", y$yname))
+    res <- fts(y$x, y$y - fits$y, start = ytsp[1], frequency = ytsp[3], 
+        xname = y$xname, yname = paste("Residuals", y$yname))
     if (weight == FALSE) {
         out <- list(x1 = as.numeric(colnames(y$y)), y1 = as.numeric(rownames(y$y)), 
             y = fts(y$x, y$y, xname = y$xname, yname = y$yname), 
             basis = basis, coeff = coeff, fitted = fits, residuals = res, 
             varprop = y.pca$varprop, wt = ts(y.pca$weights, start = ytsp[1], 
-                frequency = ytsp[3]), v = ts(y.pca$v, start = ytsp[1], frequency = ytsp[3]), 
-            basis2 = y.pca$basis2, coeff2 = y.pca$coeff2, mean.se = mean.se, 
-            call = match.call())
+                frequency = ytsp[3]), v = ts(y.pca$v, start = ytsp[1], 
+                frequency = ytsp[3]), basis2 = y.pca$basis2, 
+            coeff2 = y.pca$coeff2, mean.se = mean.se, call = match.call())
     }
     else {
         out <- list(x1 = as.numeric(colnames(y$y)), y1 = as.numeric(rownames(y$y)), 
